@@ -2,7 +2,7 @@
 This file is part of TexText, an extension for the vector
 illustration program Inkscape.
 
-opyright (c) 2006-2023 TexText developers.
+Copyright (c) 2006-2025 TexText developers.
 
 TexText is released under the 3-Clause BSD license. See
 file LICENSE.txt or go to https://github.com/textext/textext
@@ -38,6 +38,7 @@ TOOLKIT = None
 import os
 import sys
 import warnings
+import traceback
 from .errors import TexTextCommandFailed
 from textext.utility import SuppressStream
 
@@ -140,7 +141,7 @@ class AskText(object):
     CLOSE_SHORTCUT = ["Escape", "CtrlQ", "None"]
 
     def __init__(self, version_str, text, preamble_file, global_scale_factor, current_scale_factor, current_alignment,
-                 current_texcmd, current_convert_strokes_to_path, tex_commands, gui_config):
+                 current_texcmd, tex_commands, gui_config):
         self.TEX_COMMANDS = tex_commands
         if len(text) > 0:
             self.text = text
@@ -160,10 +161,22 @@ class AskText(object):
             self.current_texcmd = current_texcmd
         else:
             self.current_texcmd = self.TEX_COMMANDS[0]
-
-        self.current_convert_strokes_to_path = current_convert_strokes_to_path
+        self.using_tex = self.current_texcmd != "typst"
 
         self.preamble_file = preamble_file
+
+        # TexText < 1.10 did not use preamble files for typst and just stored
+        # the default_packages.tex. Hence, we have to correct this here.
+        if not self.using_tex and "default_packages.tex" in self.preamble_file:
+            self.preamble_file = "default_preamble_typst.typ"
+
+        if self.using_tex:
+            self.latex_default_preamble_file = self.preamble_file
+            self.typst_default_preamble_file = "default_preamble_typst.typ"
+        else:
+            self.latex_default_preamble_file = "default_packages.tex"
+            self.typst_default_preamble_file = self.preamble_file
+
         self._preamble_widget = None
         self._scale = None
         self._gui_config = gui_config
@@ -220,11 +233,13 @@ class AskTextTK(AskText):
     """TK GUI for editing TexText objects"""
 
     def __init__(self, version_str, text, preamble_file, global_scale_factor, current_scale_factor, current_alignment,
-                 current_texcmd, current_convert_strokes_to_path, tex_commands, gui_config):
+                 current_texcmd, tex_commands, gui_config):
         super(AskTextTK, self).__init__(version_str, text, preamble_file, global_scale_factor, current_scale_factor,
-                                        current_alignment, current_texcmd, current_convert_strokes_to_path, tex_commands, gui_config)
+                                        current_alignment, current_texcmd, tex_commands, gui_config)
         self._frame = None
         self._scale = None
+        self._preamble = None
+        self._askfilename_button = None
 
     @staticmethod
     def cb_cancel(widget=None, data=None):
@@ -271,7 +286,7 @@ class AskTextTK(AskText):
         label.pack(pady=2, padx=5, anchor="w")
         self._preamble = Tk.Entry(box)
         self._preamble.pack(expand=True, fill="x", ipady=4, pady=5, padx=5, side="left", anchor="e")
-        self._preamble.insert(Tk.END, self.preamble_file)
+        self.set_default_preamble()
 
         self._askfilename_button = Tk.Button(box, text="Select...",
                                        command=self.select_preamble_file)
@@ -283,24 +298,15 @@ class AskTextTK(AskText):
         box2 = Tk.Frame(self._frame, relief="flat")
         box2.pack(fill="x", pady=5, expand=True)
 
-        # Frame box for advanced settings
-        self._convert_strokes_to_path = Tk.BooleanVar()
-        self._convert_strokes_to_path.set(self.current_convert_strokes_to_path)
-        box = Tk.Frame(box2, relief="groove", borderwidth=2)
-        label = Tk.Label(box, text="SVG-output:")
-        label.pack(pady=2, padx=5, anchor="w")
-        Tk.Checkbutton(box, text="No strokes", variable=self._convert_strokes_to_path, onvalue=True, offvalue=False).pack(side="left", expand=False, anchor="w")
-        box.pack(side=Tk.RIGHT, fill="x", pady=5, expand=True)
-
         # Frame box for tex command
         self._tex_command_tk_str = Tk.StringVar()
         self._tex_command_tk_str.set(self.current_texcmd)
         box = Tk.Frame(box2, relief="groove", borderwidth=2)
-        label = Tk.Label(box, text="TeX command:")
+        label = Tk.Label(box, text="Command:")
         label.pack(pady=2, padx=5, anchor="w")
         for tex_command in self.TEX_COMMANDS:
             Tk.Radiobutton(box, text=tex_command, variable=self._tex_command_tk_str,
-                           value=tex_command).pack(side="left", expand=False, anchor="w")
+                           value=tex_command, command=self.on_texcmd_change).pack(side="left", expand=False, anchor="w")
         box.pack(side=Tk.RIGHT, fill="x", pady=5, expand=True)
 
 
@@ -402,6 +408,9 @@ class AskTextTK(AskText):
         window_ypos = (screen_height/2) - (window_height/2)
         self._root.geometry('%dx%d+%d+%d' % (window_width, window_height, window_xpos, window_ypos))
 
+        # Update status
+        self.on_texcmd_change()
+
         self._root.mainloop()
         return self._gui_config
 
@@ -414,11 +423,10 @@ class AskTextTK(AskText):
             return
         self.text = self._text_box.get(1.0, Tk.END)
         self.preamble_file = self._preamble.get()
-        self.current_convert_strokes_to_path = self._convert_strokes_to_path.get()
 
         try:
             self.callback(self.text, self.preamble_file, self.global_scale_factor, self._alignment_tk_str.get(),
-                          self._tex_command_tk_str.get(), self.current_convert_strokes_to_path)
+                          self._tex_command_tk_str.get())
         except Exception as error:
             self.show_error_dialog("TexText Error",
                               "Error occurred while converting text from Latex to SVG:",
@@ -432,6 +440,17 @@ class AskTextTK(AskText):
         self._text_box.configure(wrap=Tk.WORD if self._word_wrap_tkval.get() else Tk.NONE)
         self._gui_config["word_wrap"] = self._word_wrap_tkval.get()
 
+    def on_texcmd_change(self):
+        self.using_tex = self._tex_command_tk_str.get() != "typst"
+        self.set_default_preamble()
+
+    def set_default_preamble(self):
+        self._preamble.delete(0, Tk.END)
+        if self.using_tex:
+            self._preamble.insert(Tk.END, self.latex_default_preamble_file)
+        else:
+            self._preamble.insert(Tk.END, self.typst_default_preamble_file)
+
     def reset_scale_factor(self, _=None):
         self._scale.delete(0, "end")
         self._scale.insert(0, self.current_scale_factor)
@@ -441,9 +460,13 @@ class AskTextTK(AskText):
         self._scale.insert(0, self.global_scale_factor)
 
     def select_preamble_file(self):
+        if self.using_tex:
+            file_types = (("LaTeX files", "*.tex"), ("all files", "*.*"))
+        else:
+            file_types = (("Typst files", "*.typ"), ("all files", "*.*"))
         file_name = TkFileDialogs.askopenfilename(initialdir=os.path.dirname(self._preamble.get()),
                                                   title="Select preamble file",
-                                                  filetypes=(("LaTeX files", "*.tex"), ("all files", "*.*")))
+                                                  filetypes=file_types)
         if file_name is not None:
             self._preamble.delete(0, Tk.END)
             self._preamble.insert(Tk.END, file_name)
@@ -488,6 +511,8 @@ class AskTextTK(AskText):
             if exception.stderr:
                 add_textview('Stderr:', exception.stderr.decode('utf-8'))
 
+        add_textview('Traceback:', '\n'.join(traceback.format_exception(exception)))
+
         close_button = Tk.Button(err_dialog, text='OK', command=close_error_dialog)
         close_button.pack(side='top', fill='x', expand=True)
 
@@ -496,10 +521,9 @@ class AskTextGTKSource(AskText):
     """GTK + Source Highlighting for editing TexText objects"""
 
     def __init__(self, version_str, text, preamble_file, global_scale_factor, current_scale_factor, current_alignment,
-                 current_texcmd, current_convert_strokes_to_path, tex_commands, gui_config):
+                 current_texcmd, tex_commands, gui_config):
         super(AskTextGTKSource, self).__init__(version_str, text, preamble_file, global_scale_factor, current_scale_factor,
-                                               current_alignment, current_texcmd, current_convert_strokes_to_path,
-                                               tex_commands, gui_config)
+                                               current_alignment, current_texcmd, tex_commands, gui_config)
         self._preview = None  # type: Gtk.Image
         self._pixbuf = None  # type: GdkPixbuf
         self.preview_representation = "SCALE"  # type: str
@@ -508,6 +532,7 @@ class AskTextGTKSource(AskText):
         self._texcmd_cbox = None
         self._preview_callback = None
         self._source_view = None
+        self._preamble_delete_btn = None
 
         self.buffer_actions = [
             ('Open', Gtk.STOCK_OPEN, '_Open', '<control>O', 'Open a file', self.open_file_cb)
@@ -615,7 +640,7 @@ class AskTextGTKSource(AskText):
                 {new_node_content}
               </menu>
               <menu action='CloseShortcut'>
-                {close_shortcut} 
+                {close_shortcut}
               </menu>
               <menuitem action='ConfirmClose'/>
             </menu>
@@ -787,13 +812,10 @@ class AskTextGTKSource(AskText):
 
         self.global_scale_factor = self._scale_adj.get_value()
 
-        self.current_convert_strokes_to_path = self._conv_stroke2path.get_active()
-
         try:
             self.callback(self.text, self.preamble_file, self.global_scale_factor,
                           self.ALIGNMENT_LABELS[self._alignment_combobox.get_active()],
-                          self.TEX_COMMANDS[self._texcmd_cbox.get_active()].lower(),
-                          self.current_convert_strokes_to_path)
+                          self.TEX_COMMANDS[self._texcmd_cbox.get_active()].lower())
         except Exception as error:
             self.show_error_dialog("TexText Error",
                                    "Error occurred while converting text from Latex to SVG:",
@@ -807,6 +829,22 @@ class AskTextGTKSource(AskText):
         """Callback for Cancel button"""
         self.window_deleted_cb(widget, None, None)
 
+    def cb_compiler_changed(self, combo_box):
+        self.using_tex = self.TEX_COMMANDS[self._texcmd_cbox.get_active()] != "typst"
+        self.set_default_preamble()
+
+    def set_default_preamble(self):
+        if self.using_tex:
+            preamble_file_str = self.latex_default_preamble_file
+        else:
+            preamble_file_str = self.typst_default_preamble_file
+
+        if hasattr(Gtk, 'FileChooserButton'):
+            file_path = os.path.abspath(preamble_file_str)
+            self._preamble_widget.set_filename(file_path)
+        else:
+            self._preamble_widget.set_text(preamble_file_str)
+
     def move_cursor_cb(self, text_buffer, cursoriter, mark, view):
         self.update_position_label(text_buffer, self, view)
 
@@ -946,7 +984,7 @@ class AskTextGTKSource(AskText):
         button_box.add(self._cancel_button)
 
         self._preview_button = Gtk.Button(label="Preview")
-        self._preview_button.set_tooltip_text("Show/ update preview (CTRL+P)")
+        self._preview_button.set_tooltip_text("LaTeX only: Show/ update preview (CTRL+P)")
         button_box.add(self._preview_button)
 
         self._ok_button = Gtk.Button(stock=Gtk.STOCK_SAVE)
@@ -957,20 +995,27 @@ class AskTextGTKSource(AskText):
         self._ok_button.connect("clicked", self.cb_ok)
         self._preview_button.connect('clicked', self.update_preview)
 
+        self._texcmd_cbox.connect("changed", self.cb_compiler_changed)
+        self.cb_compiler_changed(self._texcmd_cbox)
+
         return button_box
 
     def clear_preamble(self, _=None):
         """
         Clear the preamble file setting
         """
-        self.preamble_file = "default_packages.tex"
+        if self.using_tex:
+            self.preamble_file = "default_packages.tex"
+        else:
+            self.preamble_file = "default_preamble_typst.typ"
         self.set_preamble()
 
     def set_preamble(self):
         if hasattr(Gtk, 'FileChooserButton'):
-            self._preamble_widget.set_filename(self.preamble_file)
+            file_path = os.path.abspath(self.preamble_file)
+            self._preamble_widget.set_filename(file_path)
         else:
-            self._preamble_widget.set_text(self.preamble_file)
+            self._preamble_widget.set_text(self._preamble_widget.set_filename(self.preamble_file))
 
     def reset_scale_factor(self, _=None):
         self._scale_adj.set_value(self.current_scale_factor)
@@ -1000,21 +1045,21 @@ class AskTextGTKSource(AskText):
         self.set_preamble()
 
         # --- Preamble file ---
-        preamble_delete = Gtk.Button(label="Clear")
-        preamble_delete.connect('clicked', self.clear_preamble)
-        preamble_delete.set_tooltip_text("Clear the preamble file setting")
+        self._preamble_delete_btn = Gtk.Button(label="Clear")
+        self._preamble_delete_btn.connect('clicked', self.clear_preamble)
+        self._preamble_delete_btn.set_tooltip_text("Clear the preamble file setting")
 
         preamble_frame = Gtk.Frame()
         preamble_frame.set_label("Preamble File")
         preamble_box = Gtk.HBox(homogeneous=False, spacing=0)
         preamble_frame.add(preamble_box)
         preamble_box.pack_start(self._preamble_widget, True, True, 5)
-        preamble_box.pack_start(preamble_delete, False, False, 5)
+        preamble_box.pack_start(self._preamble_delete_btn, False, False, 5)
         preamble_box.set_border_width(3)
 
         # --- Tex command ---
         texcmd_frame = Gtk.Frame()
-        texcmd_frame.set_label("TeX command")
+        texcmd_frame.set_label("Command")
         texcmd_box = Gtk.HBox(homogeneous=False, spacing=0)
         texcmd_frame.add(texcmd_box)
         texcmd_box.set_border_width(3)
@@ -1029,7 +1074,7 @@ class AskTextGTKSource(AskText):
         self._texcmd_cbox.add_attribute(renderer_text, "text", 0)
 
         self._texcmd_cbox.set_active(self.TEX_COMMANDS.index(self.current_texcmd))
-        self._texcmd_cbox.set_tooltip_text("TeX command used for compiling.")
+        self._texcmd_cbox.set_tooltip_text("Command used for compiling.")
         texcmd_box.pack_start(self._texcmd_cbox, True, True, 5)
 
         # --- Scaling ---
@@ -1096,19 +1141,10 @@ class AskTextGTKSource(AskText):
 
         alignment_box.pack_start(self._alignment_combobox, True, True, 2)
 
-        # Advanced settings
-        adv_settings_frame = Gtk.Frame()
-        adv_settings_frame.set_label("SVG output")
-        self._conv_stroke2path = Gtk.CheckButton(label="No strokes")
-        self._conv_stroke2path.set_tooltip_text("Ensures that strokes (lines, e.g. in \\sqrt, \\frac) can be easily \ncolored in Inkscape (Time consuming compilation!)")
-        self._conv_stroke2path.set_active(self.current_convert_strokes_to_path)
-        adv_settings_frame.add(self._conv_stroke2path)
-
         # --- Scale, alignment and advanced settings together in one "line"
         scale_align_hbox = Gtk.HBox(homogeneous=False, spacing=0)
         scale_align_hbox.pack_start(scale_frame, False, False, 5)
         scale_align_hbox.pack_start(alignment_frame, True, True, 5)
-        scale_align_hbox.pack_start(adv_settings_frame, True, True, 5)
 
         # --- TeX code window ---
         # Scrolling Window with Source View inside
@@ -1250,7 +1286,10 @@ class AskTextGTKSource(AskText):
                 iter = self._source_buffer.get_iter_at_offset(1)
                 self._source_buffer.place_cursor(iter)
             if new_node_content_value=='DisplayMath':
-                self.text = "$$$$"
+                if self.current_texcmd == "typst":
+                    self.text = "$  $"
+                else:
+                    self.text = "$$$$"
                 self._source_buffer.set_text(self.text)
                 iter = self._source_buffer.get_iter_at_offset(2)
                 self._source_buffer.place_cursor(iter)
@@ -1356,6 +1395,9 @@ class AskTextGTKSource(AskText):
                 add_section("Stdout: <small><i>(click to expand)</i></small>", exception.stdout.decode('utf-8'))
             if exception.stderr:
                 add_section("Stderr: <small><i>(click to expand)</i></small>", exception.stderr.decode('utf-8'))
+
+        add_section("Traceback: <small><i>(click to expand)</i></small>", '\n'.join(traceback.format_exception(exception)))
+
         dialog.show_all()
         dialog.run()
 
