@@ -2,7 +2,7 @@
 This file is part of TexText, an extension for the vector
 illustration program Inkscape.
 
-opyright (c) 2006-2023 TexText developers.
+Copyright (c) 2006-2025 TexText developers.
 
 TexText is released under the 3-Clause BSD license. See
 file LICENSE.txt or go to https://github.com/textext/textext
@@ -69,7 +69,8 @@ class LinuxDefaults(Defaults):
     executable_names = {"inkscape": ["inkscape"],
                         "pdflatex": ["pdflatex"],
                         "lualatex": ["lualatex"],
-                        "xelatex": ["xelatex"]
+                        "xelatex": ["xelatex"],
+                        "typst": ["typst"]
                         }
 
     @property
@@ -101,7 +102,8 @@ class MacDefaults(LinuxDefaults):
     executable_names = {"inkscape": ["inkscape", "inkscape-bin"],
                         "pdflatex": ["pdflatex"],
                         "lualatex": ["lualatex"],
-                        "xelatex": ["xelatex"]
+                        "xelatex": ["xelatex"],
+                        "typst": ["typst"]
                         }
 
     def get_system_path(self):
@@ -130,6 +132,7 @@ class WindowsDefaults(Defaults):
                         "pdflatex": ["pdflatex.exe"],
                         "lualatex": ["lualatex.exe"],
                         "xelatex": ["xelatex.exe"],
+                        "typst": ["typst.exe"]
                         }
 
     def __init__(self):
@@ -588,6 +591,7 @@ class TexTextRequirementsChecker(object):
         self.pdflatex_prog_name = "pdflatex"
         self.lualatex_prog_name = "lualatex"
         self.xelatex_prog_name = "xelatex"
+        self.typst_prog_name = "typst"
 
         self.inkscape_executable = None
 
@@ -620,13 +624,13 @@ class TexTextRequirementsChecker(object):
 
         return RequirementCheckResult(True, ["TkInter is found"])
 
-    def find_inkscape_1_3(self):
+    def find_inkscape_1_4(self):
         try:
             # When we call this from Inkscape we need this call
             import inkex.command as iec
             stdout_line = iec.inkscape("", version=True)
             executable = iec.which("inkscape")
-        except ImportError:
+        except (ImportError, IOError):
             try:
                 executable = self.find_executable('inkscape')['path']
                 stdout, stderr = defaults.call_command([executable, "--version"])
@@ -637,11 +641,11 @@ class TexTextRequirementsChecker(object):
         m = re.search(r"Inkscape ((\d+)\.(\d+)[-\w]*)", stdout_line)
         if m:
             found_version, major, minor = m.groups()
-            if int(major) >= 1 and int(minor) >= 3:
+            if int(major) >= 1 and int(minor) >= 4:
                 return RequirementCheckResult(True, ["inkscape=%s is found" % found_version], path=executable)
             else:
                 return RequirementCheckResult(False, [
-                    "inkscape>=1.3 is not found (but inkscape=%s is found)" % (found_version)])
+                    "inkscape>=1.4 is not found (but inkscape=%s is found)" % (found_version)])
         return RequirementCheckResult(None, ["Can't determinate inkscape version"])
         # import inkex.command as iec
         # stdout = iec.inkscape("", version=True)
@@ -729,9 +733,11 @@ class TexTextRequirementsChecker(object):
                 ]
             return result
 
+        self.logger.info(f"Python interpreter: {sys.executable}")
+
         textext_requirements = (
-            Requirement(self.find_inkscape_1_3)
-            .prepend_message("ANY", 'Detect inkscape >= 1.3')
+            Requirement(self.find_inkscape_1_4)
+            .prepend_message("ANY", 'Detect inkscape >= 1.4')
             .append_message("ERROR", help_message_with_url("preparation","inkscape"))
             .on_success(lambda result: set_inkscape(result["path"]))
             & (
@@ -744,6 +750,9 @@ class TexTextRequirementsChecker(object):
                     | Requirement(self.find_executable, self.xelatex_prog_name)
                     .on_success(lambda result: add_latex("xelatex", result["path"]))
                     .append_message("ERROR", help_message_with_url("preparation", "xelatex"))
+                    | Requirement(self.find_executable, self.typst_prog_name)
+                    .on_success(lambda result: add_latex("typst", result["path"]))
+                    .append_message("ERROR", help_message_with_url("preparation", "typst"))
             ).overwrite_check_message("Detect *latex")
             .append_message("ERROR", help_message_with_url("preparation"))
             & (
